##  Linking and Unlinking Fact Sheets to Shapes
To link fact sheets from the Inventory into existing shapes in your diagrams, do the following:
  1. Right-click on the shape you want to link. A context menu will appear; click on Link a fact sheet.
  2. The fact sheet quick search will appear, which shows you a list of all existing fact sheets in your workspace. Scroll to choose one or start typing to find the fact sheet you need.
  3. After selecting a fact sheet from the quick search, if the selected shape has no background color, the linking process will apply the fact sheet's color and its name as the label in the shape.
  4. You can unlink the fact sheet from the shape by right-clicking on the shape and clicking on Unlink fact sheet.

![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27483d7b7a4410149c00f397d519c331_LowRes.gif)
**Remember**
The shape must have been already linked to a fact sheet in the first place, or the fact sheet must have been inserted as a shape in order to unlink fact sheet and shapes.
Once the fact sheet is unlinked from a shape, the shape will keep the label and color it already had.
